@@ -6,10 +6,8 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.Enumeration;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.regex.Pattern;
 
@@ -49,7 +47,7 @@ public class LzList {
 	public LzList(Set set) {
 		base = Arrays.asList(set.toArray());
 	}
-	
+
 	/**
 	 * RXgN^
 	 * @param e
@@ -73,7 +71,7 @@ public class LzList {
 	public List list() {
 		return base;
 	}
-	
+
 	/**
 	 * or擾B
 	 * @param arg
@@ -87,7 +85,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * and擾B
 	 * @param arg
@@ -101,7 +99,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * nullȊO擾B
 	 * @param arg
@@ -115,25 +113,41 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
-	 * ComparatorBnull͍lĂȂB
+	 * ComparatorBnullΉς݁Bnull͍ŌɗB
 	 */
 	private static Comparator compStrAsc = new Comparator() {
 		public int compare(Object o1, Object o2) {
-			return o1.toString().compareTo(o2.toString());
+			if (o1 == null && o2 == null) {
+				return 0;
+			} else if (o1 == null) {
+				return 1;
+			} else if (o2 == null) {
+				return -1;
+			} else {
+				return o1.toString().compareTo(o2.toString());
+			}
 		}
 	};
-	
+
 	/**
-	 * tComparatorBnull͍lĂȂB
+	 * tComparatorBnullΉς݁Bnull͍ŌɗB
 	 */
 	private static Comparator compStrDesc = new Comparator() {
 		public int compare(Object o1, Object o2) {
-			return -(o1.toString().compareTo(o2.toString()));
+			if (o1 == null && o2 == null) {
+				return 0;
+			} else if (o1 == null) {
+				return 1;
+			} else if (o2 == null) {
+				return -11;
+			} else {
+				return -(o1.toString().compareTo(o2.toString()));
+			}
 		}
 	};
-	
+
 	/**
 	 * Ń\[gB
 	 * @return
@@ -141,7 +155,7 @@ public class LzList {
 	public LzList sortAsc() {
 		return sort(compStrAsc);
 	}
-	
+
 	/**
 	 * ~Ń\[gB
 	 * @return
@@ -149,7 +163,7 @@ public class LzList {
 	public LzList sortDesc() {
 		return sort(compStrDesc);
 	}
-	
+
 	/**
 	 * w菇Ń\[gB
 	 * @return
@@ -159,7 +173,7 @@ public class LzList {
 		Collections.sort(list, c);
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * i荞݂sBnull͏OB
 	 * @param re
@@ -177,7 +191,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * ti荞݂sBnull͏OB
 	 * @param re
@@ -195,7 +209,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * XgB
 	 * @param arg
@@ -206,7 +220,7 @@ public class LzList {
 		list.addAll(arg);
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * j[NȃXg擾B
 	 * @param arg
@@ -220,7 +234,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * ]Xg擾B
 	 * @return
@@ -233,7 +247,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * N[WɌĂяoB
 	 * @param closure
@@ -250,7 +264,7 @@ public class LzList {
 		}
 		return new LzList(list);
 	}
-	
+
 	/**
 	 * ǂeXgB
 	 * @param arg
@@ -262,7 +276,7 @@ public class LzList {
 		for (int i = 0; i < base.size(); i++) {
 			Object obj1 = base.get(i);
 			Object obj2 = arg.get(i);
-			if (obj1 == null && obj2 == null) {	
+			if (obj1 == null && obj2 == null) {
 			} else {
 				if (obj1 == null || obj2 == null) return false;
 				if (!obj1.equals(obj2)) return false;
@@ -282,7 +296,7 @@ public class LzList {
 		List sortedArg = new LzList(arg).sortAsc().list();
 		return sortedBase.equals(sortedArg);
 	}
-	
+
 	/**
 	 * ǂeXgB
 	 * @param arg
@@ -291,7 +305,7 @@ public class LzList {
 	public boolean equals(String arg) {
 		return toString().equals(arg);
 	}
-	
+
 	/**
 	 * 񉻂B
 	 * @Override
@@ -299,7 +313,7 @@ public class LzList {
 	public String toString() {
 		return base.toString();
 	}
-	
+
 	/**
 	 * EnumerationListɂB
 	 * @param e
@@ -312,7 +326,7 @@ public class LzList {
 		}
 		return result;
 	}
-	
+
 	/**
 	 * IteratorListɂB
 	 * @param i
@@ -325,5 +339,5 @@ public class LzList {
 		}
 		return result;
 	}
-	
+
 }
